pub struct XPubSocket { /* private fields */ }Trait Implementations
Sourceimpl Drop for XPubSocket
impl Drop for XPubSocket
Sourceimpl Socket for XPubSocket
impl Socket for XPubSocket
fn with_options(options: SocketOptions) -> Self
fn backend(&self) -> Arc<dyn MultiPeerBackend>
fn binds(&mut self) -> &mut HashMap<Endpoint, AcceptStopHandle>
Sourcefn monitor(&mut self) -> Receiver<SocketEvent>
fn monitor(&mut self) -> Receiver<SocketEvent>
Creates and setups new socket monitor Read more
fn new() -> Self
Sourcefn bind<'life0, 'life1, 'async_trait>(
&'life0 mut self,
endpoint: &'life1 str,
) -> Pin<Box<dyn Future<Output = ZmqResult<Endpoint>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn bind<'life0, 'life1, 'async_trait>(
&'life0 mut self,
endpoint: &'life1 str,
) -> Pin<Box<dyn Future<Output = ZmqResult<Endpoint>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Binds to the endpoint and starts a coroutine to accept new connections
on it. Read more
Sourcefn unbind<'life0, 'async_trait>(
&'life0 mut self,
endpoint: Endpoint,
) -> Pin<Box<dyn Future<Output = ZmqResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn unbind<'life0, 'async_trait>(
&'life0 mut self,
endpoint: Endpoint,
) -> Pin<Box<dyn Future<Output = ZmqResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Unbinds the endpoint, blocking until the associated endpoint is no
longer in use Read more
Sourcefn unbind_all<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Vec<ZmqError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn unbind_all<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Vec<ZmqError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Unbinds all bound endpoints, blocking until finished.
Sourceimpl SocketRecv for XPubSocket
impl SocketRecv for XPubSocket
Sourceimpl SocketSend for XPubSocket
impl SocketSend for XPubSocket
impl CaptureSocket for XPubSocket